<?php
if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}
class GP_Gpress_Comps_Tables extends WP_List_Table {

	public function get_comps($per_page = 50, $page_number = 1 , $search_term=""){
		global $wpdb;

		if($search_term == "") {
			$sql = "SELECT * FROM {$wpdb->prefix}gpress_companies ORDER by name";

			if (!empty($_REQUEST['orderby'])) {
				$sql .= ' ORDER BY ' . esc_sql($_REQUEST['orderby']);
				$sql .= !empty($_REQUEST['order']) ? ' ' . esc_sql($_REQUEST['order']) : ' ASC';
			}


			$sql .= " LIMIT $per_page";

			$sql .= ' OFFSET ' . ($page_number - 1) * $per_page;


			$result = $wpdb->get_results($sql);
			$data = array();
			foreach ($result as $k => $r) {
				$logo = $r->logo!="" ? GPRESS_URL.'includes/'.$r->logo : GPRESS_URL.'includes/images/nologo.jpg';
				$data[$k]['id'] = $r->id;
				$data[$k]['name'] = '<a href="admin.php?page=gp-companies&id='.$r->id.'">'.$this->quote_esc($r->name).'</a>';
				$data[$k]['logo'] = '<img src="'.$logo.'" style="width:100px"/>';
			}
		}else{
			$sql = "SELECT * FROM ".$wpdb->prefix."gpress_companies WHERE name LIKE '%".$this->search_quote($search_term)."%' ORDER by name LIMIT 50";
			$result = $wpdb->get_results($sql);
			$data = array();
			foreach ($result as $k => $r) {
				$logo = $r->logo!="" ? GPRESS_URL.'includes/'.$r->logo : GPRESS_URL.'includes/images/nologo.jpg';
				$data[$k]['id'] = $r->id;
				$data[$k]['name'] = '<a href="admin.php?page=gp-companies&id='.$r->id.'">'.$this->quote_esc($r->name).'</a>';
				$data[$k]['logo'] = '<img src="'.$logo.'" style="width:100px"/>';

			}
		}

		return $data;
	}

	function search_quote($text){
		$text = $this->quote_esc($text);
		return esc_attr($text);
	}

	function quote_esc($text){

		$text = htmlspecialchars_decode($text);

		$text = str_replace("\\'","'",$text);
		$text = str_replace('\"','"',$text);
		$text = str_replace("\&#039;","'",$text);
		$text = str_replace("&#039;","'",$text);
		return $text;
	}


	public function get_columns(){
		$columns = array(
			'cb'      => '<input type="checkbox" />',
			'id'      => __('<b>ID</b>','sp'),
			'name' => __('<b>'.$this->translate('Name').'</b>','sp'),
			'logo'      => __('<b>Logo</b>','sp'),
		);
		return $columns;
	}

	public function prepare_items() {
		global $wpdb;

		$search_terms = isset($_POST['s']) ? sanitize_text_field(trim($_POST['s'])) : "";
		$columns = $this->get_columns();
		$hidden = array();
		$sortable = $this->get_sortable_columns();
		$this->_column_headers = array($columns, $hidden, $sortable);
		$current_page = $this->get_pagenum();
		$sql = "SELECT COUNT(id) FROM {$wpdb->prefix}gpress_companies";
		$total_items = $wpdb->get_var($sql);
		$this->set_pagination_args(array(
			'total_items' => $total_items,
			'per_page' => 50
		));
		$this->items = $this->get_comps(50,$current_page, $search_terms);
	}
	public function column_default( $item, $column_name ) {
		switch( $column_name ) {
			case 'id':
			case 'name':
			case 'logo':
				return $item[ $column_name ];
			default:
				return print_r( $item, true ) ; //Show the whole array for troubleshooting purposes
		}
	}

	public function get_sortable_columns()
	{
		return array(
			"id" => array("id",true),
			"name" => array("name",false),
			"logo" => array("logo",false),
		);
	}

	function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="bulk-delete[]" value="%s" />', $item['id']
		);
	}

	public function get_bulk_actions() {
		$actions = array(
			'bulk-delete' => 'Delete'
		);

		return $actions;
	}

	public function column_name( $item ) {

		// create a nonce
		$delete_nonce = wp_create_nonce( 'sp_delete_customer' );

		$title = '<strong>' . $item['name'] . '</strong>';

		$actions = array(
			'delete' => sprintf( '<a href="?page=%s&action=%s&customer=%s&_wpnonce=%s">Delete</a>', esc_attr( $_REQUEST['page'] ), 'delete', absint( $item['id'] ), $delete_nonce )
		);

		return $title; //. $this->row_actions( $actions );
	}

	public function process_bulk_action() {

		//Detect when a bulk action is being triggered...
		if ( 'delete' === $this->current_action() ) {

			// In our file that handles the request, verify the nonce.
			$nonce = esc_attr( $_REQUEST['_wpnonce'] );

			if ( ! wp_verify_nonce( $nonce, 'sp_delete_customer' ) ) {
				die( 'Go get a life script kiddies' );
			}
			else {
				self::delete_customer( absint( $_GET['customer'] ) );

				wp_redirect( esc_url( add_query_arg() ) );
				exit;
			}

		}

		// If the delete bulk action is triggered
		if ( ( isset( $_POST['action'] ) && $_POST['action'] == 'bulk-delete' )
		     || ( isset( $_POST['action2'] ) && $_POST['action2'] == 'bulk-delete' )
		) {

			$delete_ids = esc_sql( $_POST['bulk-delete'] );

			// loop over the array of record IDs and delete them
			foreach ( $delete_ids as $id ) {
				self::delete_customer( $id );

			}

			wp_redirect( esc_url( add_query_arg() ) );
			exit;
		}
	}

	public function delete_customer( $id ) {
		global $wpdb;
		$result = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'gpress_companies WHERE id='.$id);
		if(count($result)>0){
			foreach ($result as $r){
				$logo = str_replace('/','\/',$r->logo);
				$name = GPRESS_FILE.'includes\/'.$logo;
			}
			unlink($name);
		}
		$wpdb->delete(
			"{$wpdb->prefix}gpress_companies",
			array( 'id' => $id ),
			array( '%d' )
		);
		$wpdb->delete(
			"{$wpdb->prefix}gpress_content_comps",
			array( 'com_id' => $id ),
			array( '%d' )
		);


	}

	function hash($text){
		return sha1(sanitize_title_with_dashes(trim($text)));
	}

	function get_lang_settings(){
		global $wpdb;
		$lang = $wpdb->get_var('SELECT settings FROM '.$wpdb->prefix.'gpress_settings WHERE type="lang"');
		$l ="";
		if(isset($lang)){
			$l = $lang;
		}
		return $l;
	}

	function translate($text){
		global $wpdb;
		$hash = $this->hash($text);
		$lang = $this->get_lang_settings();
		$result = $wpdb->get_var('SELECT translation FROM '.$wpdb->prefix.'gpress_content_langs WHERE lang_code="'.$lang.'" AND hash="'.$hash.'"');
		if(isset($result)){
			$tr = $result!="" ? $result : $text;
		}else{
			$tr = $text;
		}
		return $tr;

	}

	function list_tables(){
		echo "<div style='padding: 10px'>";
		if ( isset( $_POST['bulk-delete'] ) ) {
			foreach ( $_POST['bulk-delete'] as $id ) {
				$this->delete_customer( esc_sql( $id ) );
			}
		}
		?>
		<a href="<?php echo admin_url('admin.php?page=gp-companies&add=new')?>" class="button" style="background-color: #1ec846; color: #fff;border-color: #1ec846"><?php echo $this->translate('Add New')?></a>
		<?php
		$this->prepare_items();
		echo "<form method='post'>";
		$this->search_box( $this->translate('Search companies'), "search_cast_id" );
		$this->display();
		echo "</form>";

		echo "</div>";
	}

}
